import db from "../../db"
import { NetError, NetToolBase } from "../../utils/netTool"

class LarkBaseService extends NetToolBase {
  constructor(appName: string, requestId: string) {
    super({
      prefix: "https://open.f.mioffice.cn/open-apis",
      requestId,
      getHeaders: async () => ({
        Authorization: `Bearer ${await db.tenantAccessToken.get(appName)}`,
      }),
    })
  }

  protected async request<T = any>(params: any): Promise<T> {
    return super.request<T>(params).catch((error: NetError) => {
      const res = {
        code: error.code,
        data: null,
        message: error.message,
      } as T
      this.logger.error("larkNetTool catch error: ", JSON.stringify(res))
      return res
    })
  }
}

export default LarkBaseService
